templates Package
=================

:mod:`templates` Package
------------------------

.. automodule:: stoqlib.gui.templates
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`companytemplate` Module
-----------------------------

.. automodule:: stoqlib.gui.templates.companytemplate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`individualtemplate` Module
--------------------------------

.. automodule:: stoqlib.gui.templates.individualtemplate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`persontemplate` Module
----------------------------

.. automodule:: stoqlib.gui.templates.persontemplate
    :members:
    :undoc-members:
    :show-inheritance:

